@@ -73,7 +73,7 @@ class Remot:	# Remote comtrol base class
     self.graph_data_port = self.remote_ctl_base_port + 1
     self.remote_radio_sound_port = self.remote_ctl_base_port + 2
 
-    self.cw_delay = 0.020	# time delay to absorb WiFi jitter, in secs
+    self.cw_delay_secs = 0.020	# time delay to absorb WiFi jitter, in secs
     self.cw_phrase_begin_ts = None	# timestamp of beginning of cw phrase
     self.cw_next_event_ts = None
     self.cw_next_keydown = None
@@ -244,6 +244,10 @@ class Remot:	# Remote comtrol base class
       if command == 'HEARTBEAT':
         self.remote_ctl_heartbeat_ts = time.time()
         continue
+      # Ignore the On/Off button, Help buttons
+      if command in ("On", ".."):
+        continue
+      if DEBUG: print("Remote receive:", cmd_text)
       # buttons in idName2Button
       btn = self.app.idName2Button.get(args[0], None)
       if btn:
@@ -275,7 +279,6 @@ class Remot:	# Remote comtrol base class
         if source == "NewDecim":
           self.app.config_screen.config.btn_decimation.SetSelection(var_decim_index)
           sample_rate = self.VarDecimSet(var_decim_index)
-          print ("sample_rate", sample_rate)
           self.app.OnBtnDecimation(rate=sample_rate)
       # Json function call
       elif command == 'JsonAppFunc':
@@ -320,7 +323,7 @@ class Remot:	# Remote comtrol base class
           else:
             # Begin new cw phrase; any prior phrase should be done by now.
             # Set up first cw event to be ready to execute.
-            self.cw_begin_phrase_ts = ts + self.cw_delay
+            self.cw_begin_phrase_ts = ts + self.cw_delay_secs
         cw_new_event_ts = self.cw_begin_phrase_ts + cw_event_ts 
         if not self.cw_next_event_ts:
           self.cw_next_event_ts = cw_new_event_ts
@@ -340,9 +343,6 @@ class Remot:	# Remote comtrol base class
         if menu_item.IsCheckable():
           menu_item.Check(int(checked))
         menu.Handler(None, nid)
-      # Help buttons ".."
-      elif command == '..':
-        pass
       else:
         t = 'ERR_UNRECOGNIZED_CMD: %s\n' % cmd_text
         print(t)
