@@ -220,17 +220,16 @@ struct sound_conf {
 
 enum quisk_rec_state {
 	IDLE,
-	RECORD_RADIO,
-	RECORD_MIC,
-	PLAYBACK,
-	PLAY_FILE,
-	PLAY_SAMPLES } ;
+	TMP_RECORD_SPEAKERS,
+	TMP_RECORD_MIC,
+	TMP_PLAY_SPKR_MIC,
+	FILE_PLAY_SPKR_MIC,
+	FILE_PLAY_SAMPLES } ;
 extern enum quisk_rec_state quisk_record_state;
 
 struct wav_file {
 	FILE * fp;
 	char file_name[QUISK_PATH_SIZE];
-	int enable;
 	unsigned long samples;
 };
 
@@ -250,8 +249,8 @@ struct QuiskWav {			// data to create a WAV or RAW audio file
 // Remote Quisk control head and slave by Ben, AC2YD
 extern int remote_control_head;
 extern int remote_control_slave;
-int read_remote_radio_sound_socket(struct sound_dev* dev, complex double * cSamples, int nSamples);
-int read_remote_mic_sound_socket(struct sound_dev* dev, complex double * cSamples);
+int read_remote_radio_sound_socket(complex double * cSamples);
+int read_remote_mic_sound_socket(complex double * cSamples);
 void send_remote_radio_sound_socket(complex double * cSamples, int nSamples);
 void send_remote_mic_sound_socket(complex double * cSamples, int nSamples);
 extern PyObject * quisk_start_control_head_remote_sound(PyObject * self, PyObject * args);
@@ -320,6 +319,7 @@ extern int n_speech_sample_rate;		// Microphone decimate to speech_sample_rate,
 extern int quisk_start_cw_delay;		// milliseconds to delay output on serial or MIDI CW key down
 extern int quisk_start_ssb_delay;		// milliseconds to discard output for all modes except CW
 extern struct sound_dev * quiskPlaybackDevices[];	// array of Playback sound devices
+extern int quisk_close_file_play;
 
 extern PyObject * quisk_set_spot_level(PyObject * , PyObject *);
 extern PyObject * quisk_get_tx_filter(PyObject * , PyObject *);
