@@ -335,10 +335,6 @@ hermes_code_version = -1
 # hermes devices, you can use this to specify a unique device.  Or use -1 to accept any board.
 hermes_board_id = -1
 
-## hermes_LNA_dB			Initial LNA dB, integer
-# The initial value for the low noise Rx amplifier gain in dB.
-hermes_LNA_dB = 20
-
 ## hermes_lowpwr_tr_enable		Disable T/R in low power, boolean
 # This option only applies to the Hermes Lite 2.
 # This has no effect if the power amp is on. If the power amp is off and this setting is True,
@@ -565,10 +561,6 @@ hermes_code_version = -1
 # hermes devices, you can use this to specify a unique device.  Or use -1 to accept any board.
 hermes_board_id = -1
 
-## hermes_LNA_dB			Initial LNA dB, integer
-# The initial value for the low noise Rx amplifier gain in dB.
-hermes_LNA_dB = 20
-
 ## Hermes_BandDict		Hermes Bus, dict
 # The Hermes_BandDict sets the 7 bits on the J16 connector.
 Hermes_BandDict = {
@@ -811,10 +803,6 @@ hermes_code_version = -1
 # Hermes devices, you can use this to specify a unique device.  Or use -1 to accept any board.
 hermes_board_id = -1
 
-## hermes_LNA_dB			Initial LNA dB, integer
-# The initial value for the low noise Rx amplifier gain in dB.
-hermes_LNA_dB = 20
-
 ## Hermes_BandDict		Hermes Bus, dict
 # The Hermes_BandDict sets the 7 bits on the J16 connector.
 Hermes_BandDict = {
@@ -865,9 +853,10 @@ Hermes_BandDictEnTx = False
 ################ Receivers Control Head, Use Quisk to control a remote radio. No real hardware is used here.
 ## hardware_file_name		Hardware file path, rfile
 # Quisk can be used as a control head to control a real radio located remotely.
-# This file contains the control logic for each remote radio.
+# This file contains the control logic for remote radios of type Hermes, SoftRock or HiQSDR.
 hardware_file_name = 'ac2yd/control_softrock.py'
 #hardware_file_name = 'ac2yd/control_hermes.py'
+#hardware_file_name = 'ac2yd/control_hiqsdr.py'
 
 ## widgets_file_name		Widget file path, rfile
 # This file adds additional controls for the radio. Choose the correct file (if any) for the remote radio.
@@ -1375,9 +1364,9 @@ win_hamlib_com2_name = ""
 #win_hamlib_com2_name = "COM15"
 #win_hamlib_com2_name = "COM16"
 
-## remote_radio_ip         IP address of remote radio, text
+## remote_radio_ip         Remote radio IP or name, text
 # Quisk can be used as a control head to control a real radio located remotely.
-# This is the IP adddress of the remote radio.
+# This is the IP adddress or the host name of the remote radio.
 remote_radio_ip = ""
 #remote_radio_ip = "192.168.1.56"
 
