@@ -292,9 +292,9 @@ class SliderBoxH:
 
 class SliderBoxHH(SliderBoxH, wx.BoxSizer):
   """A horizontal control with a slider and text with a value.  The text must have a %d if display is True."""
-  def __init__(self, parent, text, init, themin, themax, handler, display):
+  def __init__(self, parent, text, init, themin, themax, handler, display, scale=1):
     wx.BoxSizer.__init__(self, wx.HORIZONTAL)
-    SliderBoxH.__init__(self, parent, text, init, themin, themax, handler, display, None, None)
+    SliderBoxH.__init__(self, parent, text, init, themin, themax, handler, display, None, None, scale)
     #font = wx.Font(10, wx.FONTFAMILY_SWISS, wx.NORMAL, wx.FONTWEIGHT_NORMAL, False, conf.quisk_typeface)
     #self.text_ctrl.SetFont(font)
     self.Add(self.text_ctrl, 0, wx.ALIGN_CENTER)
@@ -1313,7 +1313,7 @@ class _PopWindow(wx.PopupWindow):
 
 class RadioBtnPopup:
   """This class contains a button that pops up a row of radio buttons"""
-  def __init__(self, parent, command, in_labels, default):
+  def __init__(self, parent, command, in_labels, default, idName):
     self.parent = parent
     self.pop_command = command
     self.button_data = {}
@@ -1325,6 +1325,7 @@ class RadioBtnPopup:
       else:
         labels.append(item)
     self.RbDialog = _PopWindow(parent, self.OnGroupButton, labels, default)
+    self.RbDialog.RbGroup.idName = idName
     self.RbDialog.Hide()
     self.pop_control = wx.BoxSizer(wx.HORIZONTAL)
     self.first_button = QuiskPushbutton(parent, self.OnFirstButton, labels[0], text_color=conf.color_popchoice)
@@ -1537,6 +1538,10 @@ class QuiskMenu(wx.Menu):
     item.Check(is_checked)
     self.InitData(item, handler)
     return item
+  def IsItemChecked(self, item_text):
+    nid = self.item_text2id[item_text]
+    menu_item = self.FindItemById(nid)
+    return menu_item.IsChecked()
   def Handler(self, event=None, nid=0):
     if event:
       nid = event.GetId()
