@@ -75,8 +75,7 @@ struct sound_conf * pt_quisk_sound_state = &quisk_sound_state;
 char * sound_format_names[4] = {"Int32", "Int16", "Float32", "Int24"} ;
 
 static struct wav_file file_rec_audio, file_rec_samples, file_rec_mic;
-
-static int file_record_button;			// the file record button is down
+static int close_file_rec;
 
 static double digital_output_level = 0.7;
 static int dc_remove_bw=100;			// bandwidth of DC removal filter
@@ -257,13 +256,11 @@ void quisk_record_audio(struct wav_file * wavfile, complex double * cSamples, in
 			fclose(wavfile->fp);
 		wavfile->fp = fp = fopen(wavfile->file_name, "wb");
 		if ( ! fp) {
-			wavfile->enable = 0;
 			return;
 		}
 		if (fwrite("RIFF", 1, 4, fp) != 4) {
 			fclose(fp);
 			wavfile->fp = NULL;
-			wavfile->enable = 0;
 			return;
 		}
 		// pcm data, 16-bit samples, one channel
@@ -340,13 +337,11 @@ static int record_samples(struct wav_file * wavfile, complex double * cSamples,
 			fclose(wavfile->fp);
 		wavfile->fp = fp = fopen(wavfile->file_name, "wb");
 		if ( ! fp) {
-			wavfile->enable = 0;
 			return 0;
 		}
 		if (fwrite("RIFF", 1, 4, fp) != 4) {
 			fclose(fp);
 			wavfile->fp = NULL;
-			wavfile->enable = 0;
 			return 0;
 		}
 		// IEEE float data, two channels
@@ -378,7 +373,6 @@ static int record_samples(struct wav_file * wavfile, complex double * cSamples,
 		if (wavfile->fp)
 			fclose(wavfile->fp);
 		wavfile->fp = NULL;
-		wavfile->enable = 0;
 		break;
 	default:	// write the sound data to the file
 		fp = wavfile->fp;
@@ -849,6 +843,12 @@ int quisk_read_sound(void)	// Called from sound thread
 	complex double tmpSamples[SAMP_BUFFER_SIZE];
 #endif
 
+	if (close_file_rec) {
+		close_file_rec = 0;
+		quisk_record_audio(&file_rec_audio, NULL, -2);
+		quisk_record_audio(&file_rec_mic, NULL, -2);
+		record_samples(&file_rec_samples, NULL, -2);
+	}
 	//QuiskPrintTime("quisk_read_sound start", 0);
 	quisk_sound_state.interrupts++;
 	if (quisk_use_serial_port) {
@@ -939,7 +939,7 @@ int quisk_read_sound(void)	// Called from sound thread
 	if (RawSamplePlayback.handle)
 		play_sound_interface(&RawSamplePlayback, nSamples, cSamples, 0, 1.0);
 	// Perhaps replace the samples with samples from a file
-	if (quisk_record_state == PLAY_SAMPLES)
+	if (quisk_record_state == FILE_PLAY_SAMPLES)
 		quisk_play_samples(cSamples, nSamples);
 #if ! DEBUG_MIC
 	nSamples = quisk_process_samples(cSamples, nSamples);
@@ -950,15 +950,15 @@ int quisk_read_sound(void)	// Called from sound thread
 #endif
 	// For control_head role in remote control operation, receive radio sound via UDP
 	if (remote_control_head)
-		nSamples = read_remote_radio_sound_socket(&quisk_Playback, cSamples, nSamples);
+		nSamples = read_remote_radio_sound_socket(cSamples);
 	// For remote_radio role in remote control operation, send radio sound via UDP
 	if (remote_control_slave)
 		send_remote_radio_sound_socket(cSamples, nSamples);
 
 	is_DGT = rxMode == DGT_U || rxMode == DGT_L || rxMode == DGT_IQ || rxMode == DGT_FM;
-	if (quisk_record_state == PLAYBACK)
+	if (quisk_record_state == TMP_PLAY_SPKR_MIC)
 		quisk_tmp_playback(cSamples, nSamples, 1.0);		// replace radio sound
-	else if (quisk_record_state == PLAY_FILE)
+	else if (quisk_record_state == FILE_PLAY_SPKR_MIC)
 		quisk_file_playback(cSamples, nSamples, 1.0);		// replace radio sound
 	// Play the demodulated audio
 #if DEBUG_MIC != 2
@@ -999,9 +999,9 @@ int quisk_read_sound(void)	// Called from sound thread
 			cSamples[i] = 0;
 	}
 	//QuiskPrintTime("quisk_read_sound end", 0);
-	if (quisk_record_state == PLAYBACK)			// Discard previous samples and replace with saved sound
+	if (quisk_record_state == TMP_PLAY_SPKR_MIC)			// Discard previous samples and replace with saved sound
 		quisk_tmp_microphone(cSamples, mic_count);
-	else if (quisk_record_state == PLAY_FILE)	// Discard previous samples and replace with saved sound
+	else if (quisk_record_state == FILE_PLAY_SPKR_MIC)	// Discard previous samples and replace with saved sound
 		quisk_file_microphone(cSamples, mic_count);
 	if (DigitalInput.handle) {
 		if (is_DGT) {		// Discard previous mic samples and use digital samples
@@ -1026,7 +1026,7 @@ int quisk_read_sound(void)	// Called from sound thread
 
 	// For remote_radio role in remote control operation, read mic sound via UDP; replace any mic sound from above.
 	if (remote_control_slave)
-		mic_count = read_remote_mic_sound_socket(&quisk_MicPlayback, cSamples);
+		mic_count = read_remote_mic_sound_socket(cSamples);
 
 	// For control_head role in remote control operation, send mic sound via UDP
 	if (remote_control_head)
@@ -1621,7 +1621,7 @@ PyObject * quisk_sound_errors(PyObject * self, PyObject * args)
 }
 
 PyObject * quisk_set_file_name(PyObject * self, PyObject * args, PyObject * keywds)  // called from GUI
-{  // Set the names and enable state of the recording and playback files.
+{
 	int which = -1;
 	const char * name = NULL;
 	int enable = -1;
@@ -1631,54 +1631,34 @@ PyObject * quisk_set_file_name(PyObject * self, PyObject * args, PyObject * keyw
 
 	if (!PyArg_ParseTupleAndKeywords (args, keywds, "|isiii", kwlist, &which, &name, &enable, &play_button, &record_button))
 		return NULL;
-	switch (which) {
-	case 0:		// record audio file
-		if (name)
-			strMcpy(file_rec_audio.file_name, name, QUISK_PATH_SIZE);
-		if (enable != -1)
-			file_rec_audio.enable = enable;
-		break;
-	case 1:		// record sample file
-		if (name)
-			strMcpy(file_rec_samples.file_name, name, QUISK_PATH_SIZE);
-		if (enable != -1)
-			file_rec_samples.enable = enable;
-		break;
-	case 2:		// record mic file
-		if (name)
-			strMcpy(file_rec_mic.file_name, name, QUISK_PATH_SIZE);
-		if (enable != -1)
-			file_rec_mic.enable = enable;
-		break;
-	case 10:	// play audio file
-		break;
-	case 11:	// play samples file
-		break;
-	case 12:	// play CQ message file
-		break;
+	if (record_button == 0) {	// Close all recording files
+		close_file_rec = 1;
 	}
-	if (record_button != -1)
-		file_record_button = record_button;
-	if (file_rec_audio.enable && file_record_button){	// Open and Close Rx audio file
-		if ( ! file_rec_audio.fp)
-			quisk_record_audio(&file_rec_audio, NULL, -1);	// Open file
+	if (play_button == 0) {	// Close all play files
+		quisk_close_file_play = 1;
 	}
-	else if (file_rec_audio.fp) {
-		quisk_record_audio(&file_rec_audio, NULL, -2);		// Close file
-	}
-	if (file_rec_mic.enable && file_record_button){		// Open and Close microphone audio file
-		if ( ! file_rec_mic.fp)
-			quisk_record_audio(&file_rec_mic, NULL, -1);
-	}
-	else if (file_rec_mic.fp) {
-		quisk_record_audio(&file_rec_mic, NULL, -2);
-	}
-	if (file_rec_samples.enable && file_record_button){ // Open and Close I/Q samples file
-		if ( ! file_rec_samples.fp)
+	if (record_button == 1) switch (which) {
+		case 0:		// record audio file
+			if (name)
+				strMcpy(file_rec_audio.file_name, name, QUISK_PATH_SIZE);
+			quisk_record_audio(&file_rec_audio, NULL, -1);
+			break;
+		case 1:		// record sample file
+			if (name)
+				strMcpy(file_rec_samples.file_name, name, QUISK_PATH_SIZE);
 			record_samples(&file_rec_samples, NULL, -1);
-	}
-	else if (file_rec_samples.fp) {
-		record_samples(&file_rec_samples, NULL, -2);
+			break;
+		case 2:		// record mic file
+			if (name)
+				strMcpy(file_rec_mic.file_name, name, QUISK_PATH_SIZE);
+			quisk_record_audio(&file_rec_mic, NULL, -1);
+			break;
+		case 10:	// play audio file
+			break;
+		case 11:	// play samples file
+			break;
+		case 12:	// play CQ message file
+			break;
 	}
 	Py_INCREF (Py_None);
 	return Py_None;
